@@ -99,7 +99,7 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
             title='Works in Progress'
         ),
         ResumeSection.AWARDS_GRANTS: lr.SpacedSection(
-            get_awards(),
+            [award.to_pyexlatex_award() for award in get_awards()],
             title='Awards and Grants'
         ),
         ResumeSection.SOFTWARE_PROJECTS: SoftwareSection(
