@@ -54,7 +54,7 @@ CI_SKILL = SkillModel('CI/CD', 4, parents=(DEV_OPS_SKILL,), flexible_case=False)
 SEO_SKILL = SkillModel('SEO', 2, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False)
 CMS_SKILL = SkillModel('CMS', 4, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False)
 MIGRATIONS_SKILL = SkillModel('migrations', 5, parents=(DATABASE_SKILL,))
-IDE_SKILL = SkillModel('IDEs', 4, parents=(PROGRAMMING_SKILL,))
+IDE_SKILL = SkillModel('IDEs', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False)
 
 
 LINUX_SKILL = SkillModel('Linux', 4, parents=(OS_SKILL,), flexible_case=False)
